.. _powerlaw_models:

***************
Powerlaw Models
***************

- :class:`~astropy.modeling.powerlaws.PowerLaw1D`

- :class:`~astropy.modeling.powerlaws.BrokenPowerLaw1D`

- :class:`~astropy.modeling.powerlaws.SmoothlyBrokenPowerLaw1D`

- :class:`~astropy.modeling.powerlaws.ExponentialCutoffPowerLaw1D`

- :class:`~astropy.modeling.powerlaws.LogParabola1D`

- :class:`~astropy.modeling.powerlaws.Schechter1D`
